import { forwardRef } from 'react'
import type { AppProps } from 'next/app'
import CssBaseline from '@mui/material/CssBaseline'
import NextLink, { type LinkProps as NextLinkProps } from 'next/link'
import { LinkProps } from '@mui/material/Link'
import { ThemeProvider, createTheme } from '@mui/material'
import { ToastContainer } from 'react-toastify'
import styled from '@emotion/styled'
import 'react-toastify/dist/ReactToastify.css'
import '@fontsource/roboto/300.css'
import '@fontsource/roboto/400.css'
import '@fontsource/roboto/500.css'
import '@fontsource/roboto/700.css'

const NextMuiLink = forwardRef<HTMLAnchorElement, NextLinkProps>(
  function NextMuiLink(props, ref) {
    return <NextLink ref={ref} {...props} />
  },
)

const theme = createTheme({
  components: {
    MuiLink: {
      defaultProps: {
        component: NextMuiLink,
      } as LinkProps,
    },
    MuiButtonBase: {
      defaultProps: {
        LinkComponent: NextMuiLink,
      },
    },
    MuiButton: {
      styleOverrides: {
        root: {
          paddingLeft: 0,
          paddingRight: 0,
        },
      },
    },
  },
})

const StyledToastContainer = styled(ToastContainer)`
  .Toastify__toast-body {
    font-size: 0.9rem;
  }
`

export default function App({ Component, pageProps }: AppProps) {
  return (
    <ThemeProvider theme={theme}>
      <CssBaseline />
      <Component {...pageProps} />
      <StyledToastContainer
        position="top-center"
        autoClose={3000}
        hideProgressBar
        newestOnTop={false}
        closeOnClick
        pauseOnFocusLoss={false}
        pauseOnHover
      />
    </ThemeProvider>
  )
}
