import Avatar from '@mui/material/Avatar'
import Button from '@mui/material/Button'
import TextField from '@mui/material/TextField'
import Link from '@mui/material/Link'
import Grid from '@mui/material/Unstable_Grid2'
import Box from '@mui/material/Box'
import LoginIcon from '@mui/icons-material/Login'
import Typography from '@mui/material/Typography'
import Container from '@mui/material/Container'
import { useRouter } from 'next/router'
import * as yup from '@/utils/validation'
import * as api from '@/api'
import { LoginInputDto } from '@/api/user.interface'
import { useForm, SubmitHandler } from 'react-hook-form'
import { yupResolver } from '@hookform/resolvers/yup'

export default function Login() {
  const router = useRouter()

  const hookForm = useForm<LoginInputDto>({
    mode: 'onTouched',
    defaultValues: {
      email: '',
      password: '',
    },
    resolver: yupResolver(
      yup.object({
        email: yup.emailSchema,
        password: yup.string().required('请输入密码'),
      }),
    ),
  })
  const onSubmit: SubmitHandler<LoginInputDto> = async (values) => {
    const res = await api.user.login(values)
    localStorage.setItem('accessToken', res.data)
    router.push('/')
  }

  return (
    <Container
      component="main"
      maxWidth="xs"
      sx={{
        marginTop: '20vh',
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
      }}
    >
      <Avatar sx={{ bgcolor: 'primary.main' }}>
        <LoginIcon />
      </Avatar>
      <Typography component="h1" variant="h5" mt={1} mb={3}>
        登录
      </Typography>
      <Box component="form" onSubmit={hookForm.handleSubmit(onSubmit)}>
        <TextField
          {...hookForm.register('email')}
          required
          error={!!hookForm.formState.errors.email}
          helperText={hookForm.formState.errors.email?.message || ' '}
          fullWidth
          label="邮箱"
          autoComplete="email"
          autoFocus
          sx={{ mt: 1 }}
        />
        <TextField
          {...hookForm.register('password')}
          required
          error={!!hookForm.formState.errors.password}
          helperText={hookForm.formState.errors.password?.message || ' '}
          fullWidth
          label="密码"
          type="password"
          autoComplete="current-password"
          sx={{ mt: 1 }}
        />
        <Button type="submit" fullWidth variant="contained" sx={{ mt: 1 }}>
          登录
        </Button>
        <Grid container sx={{ mt: 2 }}>
          <Grid xs>
            <Link href="/forget-password" variant="body2">
              忘记密码？
            </Link>
          </Grid>
          <Grid>
            <Typography component="span" variant="body2">
              没有账号？
            </Typography>
            <Link href="/register">注册</Link>
          </Grid>
        </Grid>
      </Box>
    </Container>
  )
}
